@@ -1,7 +1,8 @@
 from sugarbowl import Function
+from .setup import setup
 
 
-class connect(Function):
+class connect(setup):
     """Decorate method to be connected to a sphinx event.
 
     Parameters
@@ -12,15 +13,10 @@ class connect(Function):
 
     # Public
 
-    MARKER = '_sphinx_settings_connect'
     protocol = Function.DECORATOR
 
     def __init__(self, event):
         self.__event = event
 
-    def __call__(self, function):
-        setattr(function, self.MARKER, self)
-        return function
-
     def invoke(self, function, app):
         app.connect(self.__event, function)
